CodecSnapshotStoreError

Enum CodecSnapshotStoreError 

#[non_exhaustive]
pub enum CodecSnapshotStoreError<S, EncErr, DecErr> { Store(S), Encode(EncErr), Decode(DecErr), EnvelopeSynthesis(ForDecodeError), }
Error from CodecSnapshotStore — the underlying store, the encoder, the decoder, or the wire-format synthesis used to call the envelope-based decode trait.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Store(S)

The underlying byte-level store failed.



Encode(EncErr)

Encoding failed.



Decode(DecErr)

Decoding failed.



EnvelopeSynthesis(ForDecodeError)

Wire-format synthesis failed while wrapping the snapshot bytes in an envelope for the codec. Practically unreachable for in-budget labels (≤64 bytes via Id::to_label) and snapshot bytes ≤ 4 GiB.